<?php

namespace App\Controller;

use App\Entity\Users;
use App\Repository\HistoryRepository;
use App\Repository\WebResetterRepository;
use Knp\Component\Pager\PaginatorInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Routing\Annotation\Route;

class HistoryController extends AbstractController
{
    #[Route('/history/{deviceId}', methods: ['GET'], name: 'app_history')]
    public function getHistory(
        HistoryRepository $historyRepository,
        WebResetterRepository $webResetterRepository,
        Request $request,
        PaginatorInterface $paginator,
        string $deviceId = null
    ): Response {
        /**
         * @var Users $user ;
         */
        $user = $this->getUser();
        $query = $historyRepository->createQueryBuilder('h')->orderBy('h.id', 'DESC');

        if ($deviceId) {
            $device = $webResetterRepository->find($deviceId);
            if (!$device) {
                throw new NotFoundHttpException();
            }

            if (!$device->getUsers()->contains($this->getUser()) && !$user->isAdminAccess()) {
                throw new AccessDeniedHttpException();
            }
            $query->andWhere('h.device = :device')
                ->setParameter(':device', $device);
        } elseif (!$user->isAdminAccess()) {
            $query->andWhere($query->expr()->in('h.device', ':devices'))
                ->setParameter('devices', $user->getWebResetter()->toArray());
        }

        $pagination = $paginator->paginate(
            $query, /* query NOT result */
            $request->query->getInt('page', 1), /*page number*/
            20 /*limit per page*/
        );

        return $this->render('pages/history.html.twig', [
            'pagination' => $pagination
        ]);
    }
}
