<?php

namespace App\Services;

use App\Entity\WebResetter as WebResetter_Entity;
use Symfony\Contracts\HttpClient\HttpClientInterface;

class WebResetter
{
    public function __construct(
        private readonly HttpClientInterface $httpClient,
        private readonly int $apiTimeout
    ) {
    }

    public function pressPowerButton(WebResetter_Entity $webResetter, bool $shortPress = true): bool|string
    {
        $response = $this->httpClient->request(
            'POST',
            'http://' . $webResetter->getServer()->getIpAddress() . '/button/power',
            [
                'json' => [
                    'deviceID' => $webResetter->getAddress(),
                    'shortPress' => $shortPress,
                    'apikey' => $webResetter->getServer()->getApikey()
                ],
                'timeout' => $this->apiTimeout
            ]
        );
        if ($response->getStatusCode() != 200) {
            return $response->getContent();
        }
        return true;
    }
    public function pressResetButton(WebResetter_Entity $webResetter, bool $shortPress = true): bool|string
    {
        $response = $this->httpClient->request(
            'POST',
            'http://' . $webResetter->getServer()->getIpAddress() . '/button/reset',
            [
                'json' => [
                    'deviceID' => $webResetter->getAddress(),
                    'shortPress' => $shortPress,
                    'apikey' => $webResetter->getServer()->getApikey()
                ],
                'timeout' => $this->apiTimeout
            ]
        );
        if ($response->getStatusCode() != 200) {
            return $response->getContent();
        }
        return true;
    }
    public function locateLED(WebResetter_Entity $webResetter, bool $powerOn = true): bool|string
    {
        $response = $this->httpClient->request(
            'POST',
            'http://' . $webResetter->getServer()->getIpAddress() . '/locate',
            [
                'json' => [
                    'deviceID' => $webResetter->getAddress(),
                    'power' => $powerOn,
                    'apikey' => $webResetter->getServer()->getApikey()
                ],
                'timeout' => $this->apiTimeout
            ]
        );
        if ($response->getStatusCode() != 200) {
            return $response->getContent();
        }
        return true;
    }

    public function shortDelay(WebResetter_Entity $webResetter, int $delay): bool|string
    {
        $response = $this->httpClient->request(
            'POST',
            'http://' . $webResetter->getServer()->getIpAddress() . '/configure/delay/short',
            [
                'json' => [
                    'deviceID' => $webResetter->getAddress(),
                    'delay' => $delay,
                    'apikey' => $webResetter->getServer()->getApikey()
                ],
                'timeout' => $this->apiTimeout
            ]
        );
        if ($response->getStatusCode() != 200) {
            return $response->getContent();
        }
        return true;
    }

    public function longDelay(WebResetter_Entity $webResetter, int $delay): bool|string
    {
        $response = $this->httpClient->request(
            'POST',
            'http://' . $webResetter->getServer()->getIpAddress() . '/configure/delay/long',
            [
                'json' => [
                    'deviceID' => $webResetter->getAddress(),
                    'delay' => $delay,
                    'apikey' => $webResetter->getServer()->getApikey()
                ],
                'timeout' => $this->apiTimeout
            ]
        );
        if ($response->getStatusCode() != 200) {
            return $response->getContent();
        }
        return true;
    }

    public function changeAddress(WebResetter_Entity $webResetter, int $newAddress): bool|string
    {
        $response = $this->httpClient->request(
            'POST',
            'http://' . $webResetter->getServer()->getIpAddress() . '/address',
            [
                'json' => [
                    'deviceID' => $webResetter->getAddress(),
                    'newAddress' => $newAddress,
                    'apikey' => $webResetter->getServer()->getApikey()
                ],
                'timeout' => $this->apiTimeout
            ]
        );
        if ($response->getStatusCode() != 200) {
            return $response->getContent();
        }
        return true;
    }

    public function reset(WebResetter_Entity $webResetter): bool|string
    {
        $response = $this->httpClient->request(
            'POST',
            'http://' . $webResetter->getServer()->getIpAddress() . '/reset',
            [
                'json' => [
                    'deviceID' => $webResetter->getAddress(),
                    'apikey' => $webResetter->getServer()->getApikey()
                ],
                'timeout' => $this->apiTimeout
            ]
        );
        if ($response->getStatusCode() != 200) {
            return $response->getContent();
        }
        return true;
    }
}
